@@ -907,7 +907,7 @@ print_version_action (GPParams __unused__ *p)
 #endif
 	printf (_("gphoto2 %s\n"
 		  "\n"
-		  "Copyright (c) 2000-%d Lutz Mueller and others\n"
+		  "Copyright (c) 2000-%d Marcus Meissner and others\n"
 		  "%s"
 		  "\n"
 		  "gphoto2 comes with NO WARRANTY, to the extent permitted by law. You may\n"
@@ -916,7 +916,7 @@ print_version_action (GPParams __unused__ *p)
 		  "\n"
 		  "This version of gphoto2 is using the following software versions and options:\n"),
 		VERSION,
-		2017, /* year of release! */
+		2019, /* year of release! */
 		port_message
 		);
 
@@ -952,6 +952,7 @@ _action_camera_capture_preview (GPParams *p, int viewasciiart)
 	
 	if (p->flags & FLAGS_STDOUT) {
 		fd = dup(fileno(stdout));
+		CR (gp_file_new_from_fd (&file, fd));
 	} else {
 		strcpy (tmpname, "tmpfileXXXXXX");
 		fd = mkstemp(tmpname);
@@ -968,7 +969,6 @@ _action_camera_capture_preview (GPParams *p, int viewasciiart)
 			tmpfilename = tmpname;
 		}
 	}
-	CR (gp_file_new_from_fd (&file, fd));
 
 #ifdef HAVE_AA
 	if (viewasciiart)
@@ -1131,7 +1131,7 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 		} else {
 			wp.type = WAIT_STRING;
 			wp.u.str = arg;
-			printf ( _("Waiting for %s event from camera. Press Ctrl-C to abort.\n"), wp.u.str);
+			printf ( _("Waiting for '%s' event from camera. Press Ctrl-C to abort.\n"), wp.u.str);
 		}
 	}
 
@@ -1255,6 +1255,14 @@ action_camera_wait_event (GPParams *p, enum download_type downloadtype, const ch
 				return GP_OK;
 			}
 			break;
+		case GP_EVENT_FILE_CHANGED:
+			fn = (CameraFilePath*)data;
+			printf("FILECHANGED %s %s\n",fn->name, fn->folder);
+			if ((wp.type == WAIT_STRING) && strstr("FILECHANGED",wp.u.str)) {
+				printf(_("event found, stopping wait!\n"));
+				return GP_OK;
+			}
+			break;
 		}
 		free (data);
 	}
